if(Sys.getenv("sb_user") == "CHANGEME") stop("must set sb_user")

# Domain to control what region data will be assembled for.
# Can be a single two or four digit HUC to limit some
# data downloads to a smaller domain. 
# can "AK", "HI", or "CONUS" to run one of them
# HUC subsetting is only supported in the superCONUS domain 
# domain = c("AK", "HI", "CONUS")
domain <- "17"

# what POI types to include
POI_types <- c( # comment / uncomment to modify
               "huc12", # a relatively uniform distribution of outlets used by IWAAs 
               "gages", # can be configured with prep_targets
               "thermo_electric", # thermo electric power plants
               "reservoirs", # reservoirs where operations data are known
               "dams", # National Inventory of Dams locations
               "waterbodies", # inlets and outlets of waterbodies
               "addition_removal", # "AR-events" from E2NHD
               "elevation_breaks", # configured in this file
               "time_of_travel", # configured in this file
               "") # leave this line alone

# CRS for projected and geographic reference systems
geo_crs <- 4326
proj_crs <- 5070

# Variables used in 01_Gage_Selection
# Earliest start data for streamgage inclusion into POI selection 
#          with mean daily streamflow
POR_Start <- as.Date("1979-10-01")
# Minimum number of days with mean daily streamflow to be considered as 
#         inclusion into POI selection (non-inclusive of start date)
min_obs <- 90

############################################
#### Variables used during POI creation ####
############################################

# Minimum drainage area for gages (square kilometers)
min_da_km_gages <- min_da_km <- 5 

# Minimum drainage area for inclusion of network outlets at the coast.
min_da_km_terminal <- 10

# Waterbody size for inclusion as POI
wb_area_thresh <- 1 

# minimum/max drainage area for headwaters(square kilometers)
min_da_km_hw <- 40
max_da_km_hw <- 60

# Max difference in elevation within a single segment/POI (centimeters)
elev_diff <- 50000 

# Max number of travel time hours between adjacent POIS
travt_diff <- 24 

# Maximum total drainage area to consider a travel time break
max_elev_TT_DA <- 10

# maximum proportional drainage area difference to collapse adjacent POIs
poi_dar_move <- .05 
poi_distance_move <- 2.5

# If the measure is within this percent of the end of a reach, don't
# add a "event" POI
reach_meas_thresh <- 10

########################################
#### Settings for refactor workflow ####
########################################

# If catchments are longer than this, split them
split_meters <- 10000

# If catchments are short than this, combine them
combine_meters <- 1000

# Target smallest catchment size for aggregation. 
# (this is a fall back only used if POIs are added to enforce network validity) 
aggregate_da_thresh_sqkm <- 5

# parallel factor for catchment reconciliation.
para_reconcile <- 2
para_split_flines <- 2
keep_cat_points <- 1

# Coefficient of areal correspondence threshold for 
# coorespondence with HUC12 in internally drained area checks
CAC_thresh <- 0.66 

# Path mods
path_mod <- FALSE
if (path_mod){
  # 7-zip
  old_path <- Sys.getenv("PATH")
  Sys.setenv(PATH = paste(old_path, "C:\\Program Files\\7-zip", sep = ";"))
  
  # Mapshaper
  old_path <- Sys.getenv("PATH") 
  Sys.setenv(PATH = paste(old_path, paste0(Sys.getenv("USERPROFILE"), "AppData\\Roaming\\npm"), sep = ";"))
  
  # Whitebox Tools
  library(whitebox)
  wbt_init(exe_path = paste0(Sys.getenv("USERPROFILE"), "AppData\\Roaming\\R\\data\\R\\whitebox\\WBT\\whitebox_tools.exe"))
}