# workspace

This is where scripts and data live. 

- _targets: contains targets project script files
- _targets_runner.R: used for manual workflow execution commands
- _targets.yaml: targets projects are declared here
- bin: folder for executable files (7z, etc).
- cache: folder for cached process files.
- data: folder for static downloaded data.
- R: folder for R source files used in workflow.
- temp: folder for temporary data.

## cache files:

The cache is used for files that the targets workflow interact with and are used or important outside the targets workflow. 

Cached outputs that have the processing unit (* in the list below) before the type signifier are based on "raster processing units". Cached outputs that have the processing unit after the type signifier are based on "vector processing units". 

- data_paths.json: all data used by the workflow is referenced here. (checked in)
- dropped_gages.csv: list of gages NOT included and why.
- Gages_info.*: gages included with useful attribues.
- reference*: by VPU files containing all reference fabric content at the native source resolution.
  - reference_flowlines
  - reference_catchments
  - POIs
  - WB
- refactor*: by VPU refactored outputs.
  - refactored_flowpaths
  - refactored_divides
  - mapped_POIs
  - lookup_table
- GF*: by VPU files containing aggregated outputs.
  - aggregated_flowpaths
  - aggregated_divides
  - mapped_POIs
  - lookup_table
- ND*: by VPU files containing contents "non-dendritic" workflow that seeks to identify areas of non-networked catchments and how to connect them to the network appropriately.
  - all_cats
  - divides_nd
  - divides_nhd
  - HUC12_nhd
  - miss_terms
  - miss_cats
- *refactor: by RPU files containing a set of refactored network artifacts preserving all network junctions from the source data.
  - reconciled_flowpaths
  - reconciled_divides
  - split_events
  - outlets
  - lookup_table
- *aggregate: by RPU files containing a set of aggregated network artifacts resolving, at a minimum the POIs in national_reference_POI.gpkg.
  - agg_cats
  - agg_flines
  - mapped_outlets
  - lookup_table

The following summarizes the role of each workflow file and targets workflow. Note that over time most of the workflow files are being migrated to targets.

## preprocess caches

- `00_get_data.Rmd` -- should be run interactively to download required data.
- `00_AK_prep.Rmd` -- prepares AK domain data. All outputs are cached and can be downloaded with `00_get_data.Rmd`.
- `00_gage_info.Rmd` -- retrieves gage information. All outputs are cached and can be downloaded with `00_get_data.Rmd`. 

## preparation

- `01_prep_targets` -- sets up basic data in VPU-based reference fabric files.
- `01_Gage_selection.Rmd` -- refines gage list for inclusion in the rest of the workflow.
- `01_HI_prep.Rmd` -- prepares the Hawaii domain for processing.

## navigate / POI selection

- `02_AK_navigate.Rmd`
- `02_HI_navigate.Rmd` 
- `02_POI_creation_targets`

These files navigate the network determining a set of required points of interest, refining the points of interest for later use (snapping/merging, etc.), and generating initial output artifacts.

## refactor

- `03_refactor_targets` -- refactors NHDPlus network for CONUS domain, eliminating very small catchments and splitting very large catchments and those with points of interest that need to be enforced in the network. Runs on an RPU basis.
- `03_hyrefactor_HI.Rmd` -- complete refactor and aggregate workflow for the HI domain.
- `03_hyrefactor_AK.Rmd` -- complete refactor and aggregate workflow for the AK domain.

## aggregation

- `04_aggregate_targets` -- aggregates network to minimal set of catchments for points of interest. Adds some additional points of interest to ensure network continuity.

## non-network handling

- `05_non_dendritic_targets` -- post processing of catchment processing aiming to identify and fill in gaps in the catchment coverage along coast lines and in closed basins that aren't otherwise included.
