library(targets)

tar_option_set(packages = c("dplyr", "sf"),
               memory = "transient", garbage_collection = TRUE, error = "stop", 
               storage = "worker", retrieval = "worker", deployment = "main", 
               iteration = "list")

library(future)
library(future.callr)
plan(multisession)

source("R/config.R")
source("R/user_vars.R")
source("R/04_aggregate_functions.R")

prep_path <- ".targets_stores/01_prep/objects/"

list(tar_target(rpu_codes_file, file.path(prep_path, "all_rpu_codes"), format = "file"),
     tar_target(rpu_codes, readRDS(rpu_codes_file)),
     tar_target(rpu_gpkg, file.path("cache", paste0(rpu_codes, "_refactor.gpkg")),
                pattern = map(rpu_codes), deployment = "worker"),
     tar_target(agg_gpkg, file.path("cache", paste0(rpu_codes, "_aggregate.gpkg")),
                pattern = map(rpu_codes), deployment = "worker"),
     tar_target(cache_split, file.path("cache", paste0(rpu_codes, ".rda")),
                pattern = map(rpu_codes)),
     
     tar_target(flowline, st_zm(read_sf(rpu_gpkg, nhd_flowline)),
                pattern = map(rpu_gpkg), deployment = "worker"),
     tar_target(outlets_POI, read_sf(rpu_gpkg, outlets_layer) |>
                  distinct() |>
                  filter(hy_id %in% flowline$COMID),
                pattern = map(rpu_gpkg, flowline), deployment = "worker"),
     
     tar_target(reconciled, read_sf(rpu_gpkg, reconciled_layer),
                pattern = map(rpu_gpkg), deployment = "worker"),
     tar_target(refactored, st_drop_geometry(read_sf(rpu_gpkg, refactored_layer)) |>
                  select(COMID, Hydroseq) |> mutate(COMID = as.integer(COMID)),
                pattern = map(rpu_gpkg), deployment = "worker"),
     tar_target(divides, st_transform(read_sf(rpu_gpkg, divide_layer), proj_crs),
                pattern = map(rpu_gpkg), deployment = "worker"),
     tar_target(highest_da, get_highest_da(read_sf(rpu_gpkg, lookup_table_refactor), 
                                           flowline, refactored),
                pattern = map(rpu_gpkg, flowline, refactored), deployment = "worker"),
     
     tar_target(aggregated, aggregate_catchments_fun(divides, reconciled, outlets_POI, 
                                                     aggregate_da_thresh_sqkm, cache_split, 
                                                     highest_da),
                pattern = map(divides, reconciled, outlets_POI, cache_split, highest_da), 
                deployment = "worker"),
     
     tar_target(long_form_pois, make_long_form_pois(aggregated$mapped_outlets_layer),
                pattern = map(aggregated), deployment = "worker"),
     
     tar_target(lookup, make_lookup(reconciled, aggregated$agg_cats_layer, aggregated$agg_fline_layer),
                pattern = map(reconciled, aggregated), deployment = "worker"),
     
     tar_target(write_agg_, {
       write_sf(aggregated$agg_cats_layer, agg_gpkg, agg_cats_layer)
       write_sf(aggregated$agg_fline_layer, agg_gpkg, agg_fline_layer)
       write_sf(aggregated$mapped_outlets_layer, agg_gpkg, mapped_outlets_layer)
       write_sf(aggregated$unmapped_outlets, agg_gpkg, "unmapped_outlets")
       write_sf(aggregated$double_outlets, agg_gpkg, "double_outlets")
       write_sf(long_form_pois, agg_gpkg, poi_data_table)
       write_sf(lookup, agg_gpkg, lookup_table_refactor)
     }, pattern = map(agg_gpkg, aggregated, long_form_pois, lookup), deployment = "worker")
)
